pub enum RegisterMemoryFileError {
TooManyFilesRegistered,
FileTooLarge,
NameAlreadyRegistered(FileId),
}Expand description
An error that can occur when registering an in-memory file
Variants
TooManyFilesRegistered
Registering another file would exceed the maximum allowed number of registered files
FileTooLarge
The files being registered exceeds the maximum allowed file size
NameAlreadyRegistered(FileId)
An in-memory file with the same name has already been registered